<?php

// $Id: Social Score $

/**
 * @file
 */

/**
 * Admin settings for socialscore.
 */
function socialscore_form(&$form) {

  $form = array();

  //Checkboxes with available content types
  $form['socialscore_content_types'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Content Types'),
    '#options' => node_get_types('names'),
    '#description' => t('Select the content types, which you want to enable social score.'),
    '#default_value' => variable_get('socialscore_content_types', array()),
  );

  //Seconds for url's statistics expiration
  $form['socialscore_seconds'] = array(
    '#type' => 'textfield',
    '#title' => t('How often do you want to synchronize your content'),
    '#maxlength' => 4,
    '#size' => 4,
    '#default_value' => variable_get('socialscore_seconds', '60'),
    '#description' => t('Time is in seconds.'),
  );

  //If the path module is enabled, show this
  if (module_exists('path')) {
    $form['socialscore_alias'] = array(
      '#type' => 'radios',
      '#title' => t('Which url do you want to use'),
      '#default_value' => variable_get('socialscore_alias', 'noalias'),
      '#options' => array(
        'noalias' => t('Synchronize the node via drupal\'s default url, for example (node/nid)'),
        'alias' => t('Synchronize the node via url alias, for example (/about)'),
        'both' => t('Synchronize the node via both default url and alias, we sum the score of each url'),
      ),
      '#description' => t('By default is Drupal\'s default url.') //ToDo: Write a description
    );
  }
  //Select Sql limit
  $form['socialscore_sql_limit'] = array(
    '#type' => 'textfield',
    '#title' => t('SQL limit for sychronization'),
    '#maxlength' => 4,
    '#size' => 4,
    '#default_value' => variable_get('socialscore_sql_limit', '100'),
    '#description' => t('Nodes per time.'),
  );

  $submodules_list = array();
  $submodules_synchro_enable_list = array();
  $active_submodules = socialscore_get_active_socialscore_submodules();
  
  foreach($active_submodules as $module) {
    $function = $module . '_recommends_synchro';
	$function($submodules_list);
	$function($submodules_synchro_enable_list, TRUE);
  }
  //Checkboxes with available submodules
  $form['socialscore_modules_recommends_synchro'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Available submodules for "cron or first time" synchronization'),
    '#options' => $submodules_list,
    '#description' => t('Select the modules, which you want to include at every synchronization.'),
    '#default_value' => $submodules_synchro_enable_list,
	'#description' => t('Although every node updates its expired socialscore while it is viewed by any user (hook_nodeapi op = "view"), you can update all your nodes at once with that batch or while cron runs (cron updates only expired nodes | batch update all nodes that are included in selected content types). Only selected submodules will make massive http requests on social networks, the others modules will just keep their old value and will send requests only at node\'s view operation.'),
  );

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit'),
  );

  return $form;
}

/**
 * Submit handler for the admin settings form.
 */
function socialscore_form_submit(&$form, $form_values) {
  variable_set('socialscore_alias', $form_values['values']['socialscore_alias']);
  variable_set('socialscore_seconds', $form_values['values']['socialscore_seconds']);
  variable_set('socialscore_content_types', $form_values['values']['socialscore_content_types']);
  variable_set('socialscore_sql_limit', $form_values['values']['socialscore_sql_limit']);
  $enabled_ckeckboxes = $form_values['values']['socialscore_modules_recommends_synchro'];
  foreach(array_keys($enabled_ckeckboxes) as $module) {
    if ($enabled_ckeckboxes[$module]) variable_set($module . '_synchro_enabled', TRUE);
	else variable_set($module . '_synchro_enabled', FALSE);
  }
  variable_set('socialscore_key', drupal_get_token('socialscore-greekteam')); //:)
  drupal_set_message(t('Your settings have been saved...'));
  drupal_set_message(t('You have made changes at social score settings. Please run the ') . l(t('sychronization batch.'), 'admin/settings/social-score/synchronization'), 'warning');
}